Package: modeest
Type: Package
Title: Mode Estimation
Version: 2.4.0
Authors@R: person("Paul", "Poncet", , "paulponcet@yahoo.fr", role = c("aut", "cre"))
Description: Provides estimators of the mode of univariate
    data or univariate distributions. 
License: GPL-3
LazyData: TRUE
Depends: R (>= 3.2)
Imports: fBasics, stable, stabledist, stats, statip (>= 0.2.3)
Suggests: evd, knitr, mvtnorm, testthat, VGAM
URL: https://github.com/paulponcet/modeest
BugReports: https://github.com/paulponcet/modeest/issues
RoxygenNote: 7.0.0
NeedsCompilation: no
Packaged: 2019-11-18 14:32:35 UTC; YL1101
Author: Paul Poncet [aut, cre]
Maintainer: Paul Poncet <paulponcet@yahoo.fr>
Repository: CRAN
Date/Publication: 2019-11-18 15:30:05 UTC
Built: R 4.6.0; ; 2026-04-27 07:04:14 UTC; unix
