# Generated by roxygen2: do not edit by hand

S3method(mlv,character)
S3method(mlv,default)
S3method(mlv,factor)
S3method(mlv,integer)
S3method(mlv,lientz)
S3method(mlv,logical)
S3method(plot,lientz)
S3method(print,lientz)
export(asselin)
export(bernMode)
export(betaMode)
export(binomMode)
export(cauchyMode)
export(chisqMode)
export(dagumMode)
export(distrMode)
export(expMode)
export(fMode)
export(fiskMode)
export(frechetMode)
export(gammaMode)
export(geomMode)
export(gevMode)
export(ghMode)
export(ghtMode)
export(gldMode)
export(gompertzMode)
export(gpdMode)
export(grenander)
export(gumbelMode)
export(hrm)
export(hsm)
export(hypMode)
export(hyperMode)
export(koenkerMode)
export(kumarMode)
export(laplaceMode)
export(lientz)
export(lnormMode)
export(logisMode)
export(lomaxMode)
export(maxwellMode)
export(meanshift)
export(mfv)
export(mfv1)
export(mlv)
export(mlv1)
export(mvnormMode)
export(naive)
export(nakaMode)
export(nbinomMode)
export(nigMode)
export(normMode)
export(paralogisticMode)
export(paretoMode)
export(parzen)
export(poisMode)
export(rayleighMode)
export(shorth)
export(skewness)
export(stableMode)
export(stableMode2)
export(tMode)
export(tsybakov)
export(unifMode)
export(venter)
export(vieu)
export(weibullMode)
export(yulesMode)
importFrom(fBasics,ghMode)
importFrom(fBasics,ghtMode)
importFrom(fBasics,gldMode)
importFrom(fBasics,hypMode)
importFrom(fBasics,nigMode)
importFrom(graphics,legend)
importFrom(graphics,locator)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(stable,stable.mode)
importFrom(stabledist,dstable)
importFrom(statip,.kernelsList)
importFrom(statip,bandwidth)
importFrom(statip,kernelfun)
importFrom(statip,mfv)
importFrom(statip,mfv1)
importFrom(statip,name2distr)
importFrom(stats,bw.SJ)
importFrom(stats,bw.bcv)
importFrom(stats,bw.nrd)
importFrom(stats,bw.nrd0)
importFrom(stats,bw.ucv)
importFrom(stats,median)
importFrom(stats,optim)
importFrom(stats,optimize)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,uniroot)
