# modeest: Estimation of the mode

The package 'modeest' provides estimators of the mode of univariate unimodal 
(and sometimes multimodal) data and values of the modes of usual probability 
distributions. 


## Installation

You can install the *release* version of `modeest` from the [CRAN](https://CRAN.R-project.org/package=modeest) with: 

```R
install.packages("modeest")
```

You can install the *development* version of `modeest` from GitHub with:

```R
# install.packages("devtools")
devtools::install_github("paulponcet/modeest")
```
