
.distributionsList <- 
function()
{
  c("beta",
    "cauchy",
    "chisq",
    "dagum",
    "exp",
    "f",
    "fisk", 
    "frechet",
    "gamma",
    "norm",
    "gev",
    "gh",
    "ght",
    "gld",
    "gompertz", 
    "gpd",
    "gumbel",
    "hyp",
    "koenker",
    "kumar",
    "laplace",
    "logis",
    "lnorm",
    "lomax",
    "maxwell", 
    "mvnorm",
    "naka",
    "nig",
    "paralogistic", 
    "pareto",
    "rayleigh",
    "stable",
    #"symstb",
    "t",
    "unif",
    "weibull",
    "yules",
    "bern",
    "binom",
    "geom",
    "hyper",
    "nbinom",
    "pois")
}
